% Dette er parameterrutinen MiniLoop_parameters. Her settes systemets
% parametere. Denne rutinen er lik for systemet uten tilbakekobling,
% systemet med trykkregulering og systemet med kaskaderegulering.
% Denne rutinen er hentet fra (Jahanshahi, 2013). Innholdet i rutinen
% har samme funksjon som tidligere, det er kun gjort estetiske 
% endringer. 


function par = MiniLoop_parameters()  

% *********** Modellens konstanter og parametere ***********
par.g = 9.81;                   % Tyngdekraften (m/s2)
par.R = 8314;                   % Gasskonstant (J/(K.Kmol))
par.rho_L = 1000;               % Vskedensiteten (Kg/m3)
par.theta= 22*pi/180;           % Fallvinkel mot bunnpunkt i stigerr
par.r1 = 0.01;                  % Raduisen til rrledning (m)
par.D1 = 2*par.r1;
par.r2 = 0.01;                  % Raduisen til stigerret (m)
par.D2 = 2*par.r2;
par.hc =2*par.r1/cos(par.theta);% Kritisk vskeniv (m)
par.A1 = pi*par.r1^2;           % Rrledningens tverrsnitt (m^2)
par.A2 = pi*par.r2^2;           % Stigerrets tverrsnitt (m^2)
par.L1 = 5;                     % Rrledningens lengde (m)
par.L2 = 3;                     % Stigerrets hyde
par.L3 = 0.2;                   % Lengden av horisontalt rr utlp(m)
par.T1 = 288;                   % Temperatur i rrledning (K)
par.T2 = 288;                   % Temperatur i stigerr (K)
par.M_G = 29;                   % Gassens molekylre vekt (kg/kmol)
par.Vb = 1.15*pi*(0.075^2);
par.V2 = par.A2*(par.L2+par.L3);% Stigerrets totale volum (m^3)
par.V1 = par.A1*par.L1;         % Rrledningens totale volum (m^3)

% *******************************************************************

par.Pnormal = 101325;           % Atmosfrisk trykk for Usg
par.Pin = par.Pnormal+38000;        
par.P0 = par.Pnormal;           % Trykk etter utlpsventilen (Pa)
Tnormal = 293.15;               % Temperatur ved normal tilstand
RTnormal =par.R*Tnormal/par.M_G;% Kompressibilitet ved normal tilstand
par.Rog_in = par.Pin/RTnormal;
par.Rog_n= par.Pnormal/RTnormal;% Gassens densitet ved normal tilstand
par.visl= 0.001002;             % Vannets viskositet ved 293.15 K (Pa.s)
par.eps = 3e-6;                 % Friksjon i rr


% *************** Stasjonre tilstandsverdier *********************
z0 = 0.1012;
P1 = par.Pnormal + 38.49e3;
P2_t = par.Pnormal + 17.22e3;
QG_in = 4.5; %l/min
QL_lin = 4; %l/min

rho_G1 = P1*par.M_G/(par.R*par.T1);



% ***********Innstrmning til rrledningen******************
wG_in = par.Rog_n*QG_in/(60*1000); %kg/s
wL_in = par.rho_L*QL_lin/(60*1000); %kg/s

w_G1 = wG_in;
w_L1 = wL_in;
wG_out = wG_in;
wL_out = wL_in;
w_mix = wG_out + wL_out;





% ******* Initielle verdier i rrledningen ***********
Alpha_L1_av = wL_in*rho_G1/(wL_in*rho_G1 + wG_in*par.rho_L); 
par.k_h = 1;
h1ss = par.k_h*Alpha_L1_av*par.hc;
h1 = h1ss;

Uslin = wL_in/(par.A1*par.rho_L);
Re1=par.rho_L*Uslin*(2*par.r1)/par.visl;

temp = -1.8*log10((par.eps/par.D1/3.7)^1.11+6.9/Re1);
Lambda1 = (1/temp)^2;
Fric_pipe = Alpha_L1_av*Lambda1*par.rho_L*Uslin^2*par.L1/(2*par.r1);

par.Alpha_L1_av = Alpha_L1_av;



%************ Initielle verdier i stigerret ******************
P2_av = (P1+par.rho_L*par.g*h1-Fric_pipe+P2_t)/2;
rho_G2_av = (P2_av)*par.M_G/(par.R*par.T2);
Alpha_L2_av = rho_G2_av*wL_in/(rho_G2_av*wL_in+par.rho_L*wG_in);
rho_mix_av = rho_G2_av*(1-Alpha_L2_av)+par.rho_L*Alpha_L2_av;

Usl2 = wL_in/(par.rho_L*par.A2);
Usg2 = wG_in/(rho_G2_av*par.A2);
Um = Usl2 + Usg2;

Re2 = rho_mix_av*Um*2*par.r2/par.visl;
temp = -1.8*log10((par.eps/par.D2/3.7)^1.11+6.9/Re2);
Lambda2 = (1/temp)^2;

Fric_riser = Alpha_L2_av*Lambda2*rho_mix_av*Um^2*(par.L2+par.L3)/(2*par.r2);


P2_b = P2_t + rho_mix_av*par.g*par.L2 + Fric_riser;

rho_G2 = P2_t*par.M_G/(par.R*par.T2);
Alpha_Lt = rho_G2*w_L1/(rho_G2*w_L1+par.rho_L*w_G1);

rho_t = Alpha_Lt*par.rho_L + (1-Alpha_Lt)*rho_G2;

A_g = (h1<par.hc)*(par.A1/par.hc^2)*(par.hc - h1)^2;
A_l = par.A1 - A_g;

v_G1 = w_G1/(rho_G1*A_g);



%% Beregner korrelasjonskoeffisienter

par.K_g = 1.3*v_G1/sqrt((P1-Fric_pipe-P2_b)/rho_G1);

par.K_o = 1.35*w_L1/(A_l*sqrt(par.rho_L*(P1-Fric_pipe+par.rho_L*par.g*h1-P2_b)));

par.K_pc = 1*w_mix/(z0*sqrt(rho_t*(P2_t-par.P0)));

end